==> owncloud-5.0.0.tar.bz2: owncloud/apps/files/l10n/oc.php <==
<?php $TRANSLATIONS = array(
"There is no error, the file uploaded with success" => "Amontcargament capitat, pas d'errors",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Lo fichièr amontcargat es mai gròs que la directiva «MAX_FILE_SIZE» especifiada dins lo formulari HTML",
"The uploaded file was only partially uploaded" => "Lo fichièr foguèt pas completament amontcargat",
"No file was uploaded" => "Cap de fichièrs son estats amontcargats",
"Missing a temporary folder" => "Un dorsièr temporari manca",
"Failed to write to disk" => "L'escriptura sul disc a fracassat",
"Files" => "Fichièrs",
"Delete" => "Escafa",
"Rename" => "Torna nomenar",
"Pending" => "Al esperar",
"replace" => "remplaça",
"suggest name" => "nom prepausat",
"cancel" => "anulla",
"undo" => "defar",
"Unable to upload your file as it is a directory or has 0 bytes" => "Impossible d'amontcargar lo teu fichièr qu'es un repertòri o que ten pas que 0 octet.",
"Upload Error" => "Error d'amontcargar",
"1 file uploading" => "1 fichièr al amontcargar",
"Upload cancelled." => "Amontcargar anullat.",
"File upload is in progress. Leaving the page now will cancel the upload." => "Un amontcargar es a se far. Daissar aquesta pagina ara tamparà lo cargament. ",
"Name" => "Nom",
"Size" => "Talha",
"Modified" => "Modificat",
"Upload" => "Amontcarga",
"File handling" => "Manejament de fichièr",
"Maximum upload size" => "Talha maximum d'amontcargament",
"max. possible: " => "max. possible: ",
"Needed for multi-file and folder downloads." => "Requesit per avalcargar gropat de fichièrs e dorsièr",
"Enable ZIP-download" => "Activa l'avalcargament de ZIP",
"0 is unlimited" => "0 es pas limitat",
"Maximum input size for ZIP files" => "Talha maximum de dintrada per fichièrs ZIP",
"Save" => "Enregistra",
"New" => "Nòu",
"Text file" => "Fichièr de tèxte",
"Folder" => "Dorsièr",
"Cancel upload" => " Anulla l'amontcargar",
"Nothing in here. Upload something!" => "Pas res dedins. Amontcarga qualquaren",
"Download" => "Avalcarga",
"Unshare" => "Non parteja",
"Upload too large" => "Amontcargament tròp gròs",
"The files you are trying to upload exceed the maximum size for file uploads on this server." => "Los fichièrs que sias a amontcargar son tròp pesucs per la talha maxi pel servidor.",
"Files are being scanned, please wait." => "Los fiichièrs son a èsser explorats, ",
"Current scanning" => "Exploracion en cors"
);

==> owncloud_7.0.4+dfsg.orig.tar.bz2: owncloud/apps/files/l10n/oc.php <==
<?php
$TRANSLATIONS = array(
"There is no error, the file uploaded with success" => "Amontcargament capitat, pas d'errors",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Lo fichièr amontcargat es mai gròs que la directiva «MAX_FILE_SIZE» especifiada dins lo formulari HTML",
"The uploaded file was only partially uploaded" => "Lo fichièr foguèt pas completament amontcargat",
"No file was uploaded" => "Cap de fichièrs son estats amontcargats",
"Missing a temporary folder" => "Un dorsièr temporari manca",
"Failed to write to disk" => "L'escriptura sul disc a fracassat",
"Files" => "Fichièrs",
"Upload cancelled." => "Amontcargar anullat.",
"File upload is in progress. Leaving the page now will cancel the upload." => "Un amontcargar es a se far. Daissar aquesta pagina ara tamparà lo cargament. ",
"Share" => "Parteja",
"Delete" => "Escafa",
"Rename" => "Torna nomenar",
"Pending" => "Al esperar",
"Error" => "Error",
"Name" => "Nom",
"Size" => "Talha",
"Modified" => "Modificat",
"_%n folder_::_%n folders_" => array("",""),
"_%n file_::_%n files_" => array("",""),
"_Uploading %n file_::_Uploading %n files_" => array("",""),
"File handling" => "Manejament de fichièr",
"Maximum upload size" => "Talha maximum d'amontcargament",
"max. possible: " => "max. possible: ",
"Save" => "Enregistra",
"New" => "Nòu",
"Text file" => "Fichièr de tèxte",
"Folder" => "Dorsièr",
"Nothing in here. Upload something!" => "Pas res dedins. Amontcarga qualquaren",
"Download" => "Avalcarga",
"Upload too large" => "Amontcargament tròp gròs",
"The files you are trying to upload exceed the maximum size for file uploads on this server." => "Los fichièrs que sias a amontcargar son tròp pesucs per la talha maxi pel servidor.",
"Files are being scanned, please wait." => "Los fiichièrs son a èsser explorats, "
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";
